@@ -114,6 +114,8 @@
         <translation>
             <numerusform>שעה</numerusform>
             <numerusform>שעתיים</numerusform>
+            <numerusform>%Ln שעות</numerusform>
+            <numerusform>%Ln שעות</numerusform>
         </translation>
     </message>
     <message numerus="yes">
@@ -122,6 +124,8 @@
         <translation>
             <numerusform>דקה</numerusform>
             <numerusform>שתי דקות</numerusform>
+            <numerusform>%Ln דקות</numerusform>
+            <numerusform>%Ln דקות</numerusform>
         </translation>
     </message>
     <message>
@@ -234,6 +238,8 @@
         <translation>
             <numerusform>תתבצע השהיה בעוד שנייה</numerusform>
             <numerusform>תתבצע השהיה בעוד שתי שניות</numerusform>
+            <numerusform>תתבצע השהיה בעוד %Ln שניות</numerusform>
+            <numerusform>תתבצע השהיה בעוד %Ln שניות</numerusform>
         </translation>
     </message>
     <message numerus="yes">
@@ -241,6 +247,8 @@
         <source>Hibernating in %Ln second(s)</source>
         <translation>
             <numerusform>תתבצע הרדמה בעוד שנייה</numerusform>
+            <numerusform>תתבצע הרדמה בעוד שתי שניות</numerusform>
+            <numerusform>תתבצע הרדמה בעוד %Ln שניות</numerusform>
             <numerusform>תתבצע הרדמה בעוד %Ln שניות</numerusform>
         </translation>
     </message>
@@ -250,6 +258,8 @@
         <translation>
             <numerusform>יתבצע כיבוי בעוד שנייה</numerusform>
             <numerusform>יתבצע כיבוי בעוד שתי שניות</numerusform>
+            <numerusform>יתבצע כיבוי בעוד %Ln שניות</numerusform>
+            <numerusform>יתבצע כיבוי בעוד %Ln שניות</numerusform>
         </translation>
     </message>
 </context>
